v3c_alert library

Classes

V3CAlert
A customizable alert dialog widget for Flutter applications.

Enums

V3CAlertType
Defines the type of alert dialog to display, such as success, error, info, or warning. Defines the type of alert dialog to display, such as success, error, info, or warning.